built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;DBus;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Pdf;PdfWidgets;Positioning;Location;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickTest;QuickWidgets;Scxml;Sensors;SerialPort;StateMachine;TextToSpeech;SpatialAudio;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebEngineCore;WebEngineWidgets;WebEngineQuick;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
    .split(";"))

shiboken_library_soversion = "6.11"
pyside_library_soversion = "6.11"

version = "6.11.2"
version_info = (6, 11, 2, "", "")

__build_date__ = '2026-08-18T10:02:11+00:00'
__build_commit_date__ = '2026-08-17T20:32:46+00:00'
__build_commit_hash__ = '5ae91fc0533035f19071ee469f239ac2b1cc6242'




